@@ -23,6 +23,8 @@
 #include <QTemporaryFile>
 #include <QTextStream>
 
+using namespace Qt::StringLiterals;
+
 static void parseFsSpec(const QString& m_fsSpec, FstabEntry::Type& m_entryType, QString& m_deviceNode);
 static QString findBlkIdDevice(const char *token, const QString& value);
 static void writeEntry(QTextStream& s, const FstabEntry& entry, std::array<unsigned int, 4> columnWidth);
@@ -284,6 +286,11 @@ static void writeEntry(QTextStream& s, const FstabEntry& entry, std::array<unsig
         return;
     }
 
+    // "none" is only valid as mount point for swap partitions
+    if ((entry.mountPoint().isEmpty() || entry.mountPoint() == u"none"_s) && entry.type() != QStringLiteral("swap")) {
+        return;
+    }
+
     s.setFieldAlignment(QTextStream::AlignLeft);
     s.setFieldWidth(columnWidth[0]);
     s << entry.fsSpec()
@@ -295,7 +302,7 @@ static void writeEntry(QTextStream& s, const FstabEntry& entry, std::array<unsig
       << entry.comment() << "\n";
 }
 
-bool writeMountpoints(const FstabEntryList& fstabEntries)
+QString generateFstab(const FstabEntryList& fstabEntries)
 {
     QString fstabContents;
     QTextStream out(&fstabContents);
@@ -305,6 +312,14 @@ bool writeMountpoints(const FstabEntryList& fstabEntries)
     for (const auto &e : fstabEntries)
         writeEntry(out, e, columnWidth);
 
+    out.flush();
+    return fstabContents;
+}
+
+bool writeMountpoints(const FstabEntryList& fstabEntries)
+{
+    auto fstab = generateFstab(fstabEntries);
+
     ExternalCommand cmd;
-    return cmd.writeFstab(fstabContents.toLocal8Bit());
+    return cmd.writeFstab(fstab.toLocal8Bit());
 }
