@@ -160,14 +160,14 @@ bool ext2::create(Report& report, const QString& deviceNode)
     if (!this->features().isEmpty()) {
         QStringList feature_list = QStringList();
         for (const auto& k : this->features().keys()) {
-	    const auto& v = this->features().value(k);
-            if (v.type() == QVariant::Type::Bool) {
+            const auto& v = this->features().value(k);
+            if (v.typeId() == QMetaType::Type::Bool) {
                 if (v.toBool())
                     feature_list << k;
-		else
+            else
                     feature_list << (QStringLiteral("^") +  k);
             } else {
-                qWarning() << "Ignoring feature" << k << "of type" << v.type() << "; requires type QVariant::bool.";
+                qWarning() << "Ignoring feature" << k << "of type" << v.typeId() << "; requires type QMetaType::Type:Bool.";
             }
         }
         args << QStringLiteral("-O") << feature_list.join(QStringLiteral(","));
